pub enum BaselineModeArg {
Count,
Identity,
}Expand description
CLI mirror of fallow_engine::baseline::HealthBaselineMode.
Variants
Count
Match a saved health baseline per file and finding category.
Identity
Match a saved health baseline per function identity and finding category, so a hotspot that replaces another hotspot is reported.