pub fn load(root: &Path) -> ImpactStoreExpand description
Load the store. Missing or unreadable files fall back to defaults; unreadable files are warned about rather than silently disabling tracking.
pub fn load(root: &Path) -> ImpactStoreLoad the store. Missing or unreadable files fall back to defaults; unreadable files are warned about rather than silently disabling tracking.