pub fn save_regression_baseline(
path: &Path,
root: &Path,
check_counts: Option<&CheckCounts>,
dupes_counts: Option<&DupesCounts>,
output: OutputFormat,
) -> Result<(), ExitCode>Expand description
Save the current analysis results as a regression baseline.
Errors
Returns an error if the baseline cannot be serialized or written to disk.