pub fn print_health_performance(timings: &HealthTimings, format: OutputFormat)Expand description
Print health pipeline performance timings. In JSON mode, outputs to stderr to avoid polluting the JSON analysis output on stdout.
pub fn print_health_performance(timings: &HealthTimings, format: OutputFormat)Print health pipeline performance timings. In JSON mode, outputs to stderr to avoid polluting the JSON analysis output on stdout.