pub fn print_performance(timings: &PipelineTimings, format: &OutputFormat)Expand description
Print pipeline performance timings. In JSON mode, outputs to stderr to avoid polluting the JSON analysis output on stdout.
pub fn print_performance(timings: &PipelineTimings, format: &OutputFormat)Print pipeline performance timings. In JSON mode, outputs to stderr to avoid polluting the JSON analysis output on stdout.