pub fn resolve_render_options(root: &Path) -> RenderOptionsExpand description
Resolve render options from the process environment and the analysis root.
pub fn resolve_render_options(root: &Path) -> RenderOptionsResolve render options from the process environment and the analysis root.