pub fn resolve_owner(
path: &Path,
root: &Path,
resolver: &OwnershipResolver,
) -> StringExpand description
Resolve the group key for a single path (for per-result tagging in SARIF/CodeClimate).
pub fn resolve_owner(
path: &Path,
root: &Path,
resolver: &OwnershipResolver,
) -> StringResolve the group key for a single path (for per-result tagging in SARIF/CodeClimate).