is_redirected

Function is_redirected 

pub fn is_redirected() -> bool
Whether report content is currently being redirected to a file. Used to gate interactive terminal chrome that must not land in the file.