Health / complexity analysis report types. Health / complexity analysis report types.
Separated from the health command module so that report formatters
(which are compiled as part of both the lib and bin targets) can
reference these types without pulling in binary-only dependencies.
Structs
- File
Health Score - Per-file health score combining complexity, coupling, and dead code metrics.
- Health
Finding - A single function that exceeds a complexity threshold.
- Health
Report - Result of complexity analysis for reporting.
- Health
Summary - Summary statistics for the health report.
- Hotspot
Entry - A hotspot: a file that is both complex and frequently changing.
- Hotspot
Summary - Summary statistics for hotspot analysis.
Enums
- Exceeded
Threshold - Which complexity threshold was exceeded.