Module health_types

Module health_types 

Health / complexity analysis report types. Health / complexity analysis report types.

Separated from the health command module so that report formatters (which are compiled as part of both the lib and bin targets) can reference these types without pulling in binary-only dependencies.

Structs

HealthFinding
A single function that exceeds a complexity threshold.
HealthReport
Result of complexity analysis for reporting.
HealthSummary
Summary statistics for the health report.

Enums

ExceededThreshold
Which complexity threshold was exceeded.