Report formatting utilities for analysis results.
Exposed for snapshot testing of output formats.
Enums
- Level
- Severity level for human-readable output.
Functions
- build_
codeclimate - Build CodeClimate JSON array from dead-code analysis results.
- build_
compact_ lines - Build compact output lines for analysis results.
Each issue is represented as a single
prefix:detailsline. - build_
duplication_ codeclimate - Build CodeClimate JSON array from duplication analysis results.
- build_
duplication_ markdown - Build markdown output for duplication results.
- build_
health_ codeclimate - Build CodeClimate JSON array from health/complexity analysis results.
- build_
health_ markdown - Build markdown output for health (complexity) results.
- build_
health_ sarif - build_
json - Build the JSON output value for analysis results.
- build_
markdown - Build markdown output for analysis results.
- build_
sarif - elide_
common_ prefix - Elide the common directory prefix between a base path and a target path.
Only strips complete directory segments (never partial filenames).
Returns the remaining suffix of
target. - normalize_
uri - Normalize a path string to a valid URI: forward slashes and percent-encoded brackets.
- print_
clone_ trace - Print clone trace results.
- print_
cross_ reference_ findings - Print cross-reference findings (duplicated code that is also dead code).
- print_
dependency_ trace - Print dependency trace results.
- print_
duplication_ report - Print duplication analysis results in the configured format.
- print_
export_ trace - Print export trace results.
- print_
file_ trace - Print file trace results.
- print_
health_ report - Print health (complexity) analysis results in the configured format.
- print_
performance - Print pipeline performance timings. In JSON mode, outputs to stderr to avoid polluting the JSON analysis output on stdout.
- print_
results - Print analysis results in the configured format. Returns exit code 2 if serialization fails, SUCCESS otherwise.
- relative_
path - Strip the project root prefix from a path for display, falling back to the full path.
- severity_
to_ level - split_
dir_ filename - Split a path string into (directory, filename) for display.
Directory includes the trailing
/. If no directory, returns("", filename).