Structs
Enums
Functions
- category_
for_ rule - Map a fallow rule id to its category for sticky-comment grouping.
- command_
title - escape_
md - Escape a string for inclusion in a Markdown table cell.
- issues_
from_ codeclimate - print_
pr_ comment - render_
pr_ comment - set_
workspace_ marker_ from_ list - Set the workspace marker from a
--workspaceselection list.