Module pr_comment

Module pr_comment 

Structs

CiIssue

Enums

Provider

Functions

category_for_rule
Map a fallow rule id to its category for sticky-comment grouping.
command_title
escape_md
Escape a string for inclusion in a Markdown table cell.
issues_from_codeclimate
print_pr_comment
render_pr_comment
set_workspace_marker_from_list
Set the workspace marker from a --workspace selection list.