pub fn build_baseline_deltas_json<'a>(
total_delta: i64,
per_category: impl Iterator<Item = (&'a str, usize, usize, i64)>,
) -> ValueExpand description
Build a JSON representation of baseline deltas for the combined JSON envelope.
Accepts a total delta and an iterator of per-category entries to avoid
coupling the report module (compiled in both lib and bin) to the
binary-only baseline module.